==> adam-core-0.12.1-sources.jar: org/bdgenomics/adam/predicates/LocusPredicate.scala <==
/**
 * Licensed to Big Data Genomics (BDG) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The BDG licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.bdgenomics.adam.predicates

import parquet.filter.{ RecordFilter, UnboundRecordFilter }

import java.lang.Iterable
import parquet.column.ColumnReader
import parquet.filter.AndRecordFilter.and
import parquet.filter.ColumnPredicates.equalTo
import parquet.filter.ColumnRecordFilter.column
import org.bdgenomics.adam.projections.ADAMRecordField

class LocusPredicate extends UnboundRecordFilter {

  def bind(readers: Iterable[ColumnReader]): RecordFilter = {
    and(column(ADAMRecordField.readMapped.toString(), equalTo(true)),
      and(column(ADAMRecordField.primaryAlignment.toString(), equalTo(true)),
        and(column(ADAMRecordField.failedVendorQualityChecks.toString(), equalTo(false)),
          column(ADAMRecordField.duplicateRead.toString(), equalTo(false))))).bind(readers)
  }
}

==> adam-core-0.15.0-sources.jar: org/bdgenomics/adam/predicates/LocusPredicate.scala <==
/**
 * Licensed to Big Data Genomics (BDG) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The BDG licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.bdgenomics.adam.predicates

import parquet.filter.{ RecordFilter, UnboundRecordFilter }

import java.lang.Iterable
import parquet.column.ColumnReader
import parquet.filter.AndRecordFilter.and
import parquet.filter.ColumnPredicates.equalTo
import parquet.filter.ColumnRecordFilter.column
import org.bdgenomics.adam.projections.AlignmentRecordField

class LocusPredicate extends UnboundRecordFilter {

  def bind(readers: Iterable[ColumnReader]): RecordFilter = {
    and(column(AlignmentRecordField.readMapped.toString(), equalTo(true)),
      and(column(AlignmentRecordField.primaryAlignment.toString(), equalTo(true)),
        and(column(AlignmentRecordField.failedVendorQualityChecks.toString(), equalTo(false)),
          column(AlignmentRecordField.duplicateRead.toString(), equalTo(false))))).bind(readers)
  }
}
